Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(268)

Unified Diff: gslib/help_provider.py

Issue 698893003: Update checked in version of gsutil to version 4.6 (Closed) Base URL: http://dart.googlecode.com/svn/third_party/gsutil/
Patch Set: Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « gslib/hashing_helper.py ('k') | gslib/ls_helper.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: gslib/help_provider.py
===================================================================
--- gslib/help_provider.py (revision 33376)
+++ gslib/help_provider.py (working copy)
@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
# Copyright 2012 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
@@ -11,82 +12,77 @@
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
+"""Module defining help types and providers for gsutil commands."""
+from __future__ import absolute_import
+
+import collections
from gslib.exception import CommandException
-class HelpType(object):
- COMMAND_HELP = 'command_help'
- ADDITIONAL_HELP = 'additional_help'
+ALL_HELP_TYPES = ['command_help', 'additional_help']
-ALL_HELP_TYPES = [HelpType.COMMAND_HELP, HelpType.ADDITIONAL_HELP]
-
-# help_spec key constants.
-HELP_NAME = 'help_name'
-HELP_NAME_ALIASES = 'help_name_aliases'
-HELP_TYPE = 'help_type'
-HELP_ONE_LINE_SUMMARY = 'help_one_line_summary'
-HELP_TEXT = 'help_text'
-SUBCOMMAND_HELP_TEXT = 'subcommand_help_text'
-
# Constants enforced by SanityCheck
MAX_HELP_NAME_LEN = 15
MIN_ONE_LINE_SUMMARY_LEN = 10
MAX_ONE_LINE_SUMMARY_LEN = 80 - MAX_HELP_NAME_LEN
-REQUIRED_SPEC_KEYS = [HELP_NAME, HELP_NAME_ALIASES, HELP_TYPE,
- HELP_ONE_LINE_SUMMARY, HELP_TEXT]
-
DESCRIPTION_PREFIX = """
<B>DESCRIPTION</B>"""
SYNOPSIS_PREFIX = """
<B>SYNOPSIS</B>"""
+
class HelpProvider(object):
"""Interface for providing help."""
- # Each subclass must define the following map.
- help_spec = {
- # Name of command or auxiliary help info for which this help applies.
- HELP_NAME : None,
- # List of help name aliases.
- HELP_NAME_ALIASES : None,
- # HelpType.
- HELP_TYPE : None,
- # One line summary of this help.
- HELP_ONE_LINE_SUMMARY : None,
- # The full help text.
- HELP_TEXT : None,
- }
+ # Each subclass of HelpProvider define a property named 'help_spec' that is
+ # an instance of the following class.
+ HelpSpec = collections.namedtuple('HelpSpec', [
+ # Name of command or auxiliary help info for which this help applies.
+ 'help_name',
+ # List of help name aliases.
+ 'help_name_aliases',
+ # Type of help.
+ 'help_type',
+ # One line summary of this help.
+ 'help_one_line_summary',
+ # The full help text.
+ 'help_text',
+ # Help text for subcommands of the command's help being specified.
+ 'subcommand_help_text',
+ ])
+ # Each subclass must override this with an instance of HelpSpec.
+ help_spec = None
+
+
# This is a static helper instead of a class method because the help loader
# (gslib.commands.help._LoadHelpMaps()) operates on classes not instances.
def SanityCheck(help_provider, help_name_map):
"""Helper for checking that a HelpProvider has minimally adequate content."""
- for k in REQUIRED_SPEC_KEYS:
- if k not in help_provider.help_spec or help_provider.help_spec[k] is None:
- raise CommandException('"%s" help implementation is missing %s '
- 'specification' % (help_provider.help_name, k))
# Sanity check the content.
- assert (len(help_provider.help_spec[HELP_NAME]) > 1
- and len(help_provider.help_spec[HELP_NAME]) < MAX_HELP_NAME_LEN)
- for hna in help_provider.help_spec[HELP_NAME_ALIASES]:
- assert len(hna) > 0
- one_line_summary_len = len(help_provider.help_spec[HELP_ONE_LINE_SUMMARY])
+ assert (len(help_provider.help_spec.help_name) > 1
+ and len(help_provider.help_spec.help_name) < MAX_HELP_NAME_LEN)
+ for hna in help_provider.help_spec.help_name_aliases:
+ assert hna
+ one_line_summary_len = len(help_provider.help_spec.help_one_line_summary)
assert (one_line_summary_len > MIN_ONE_LINE_SUMMARY_LEN
and one_line_summary_len < MAX_ONE_LINE_SUMMARY_LEN)
- assert len(help_provider.help_spec[HELP_TEXT]) > 10
+ assert len(help_provider.help_spec.help_text) > 10
# Ensure there are no dupe help names or aliases across commands.
- name_check_list = [help_provider.help_spec[HELP_NAME]]
- name_check_list.extend(help_provider.help_spec[HELP_NAME_ALIASES])
+ name_check_list = [help_provider.help_spec.help_name]
+ name_check_list.extend(help_provider.help_spec.help_name_aliases)
for name_or_alias in name_check_list:
if help_name_map.has_key(name_or_alias):
raise CommandException(
'Duplicate help name/alias "%s" found while loading help from %s. '
- 'That name/alias was already taken by %s' % (name_or_alias,
- help_provider.__module__, help_name_map[name_or_alias].__module__))
-
+ 'That name/alias was already taken by %s' % (
+ name_or_alias, help_provider.__module__,
+ help_name_map[name_or_alias].__module__))
+
+
def CreateHelpText(synopsis, description):
"""Helper for adding help text headers given synopsis and description."""
return SYNOPSIS_PREFIX + synopsis + DESCRIPTION_PREFIX + description
« no previous file with comments | « gslib/hashing_helper.py ('k') | gslib/ls_helper.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698